# Running Prune and Retrain process with One Line of Code
It can choose the hyper-parameters such as the pruning ratio and sparsity type according to the accuracy and speed requirement. Then it start to prune and retrain the model. Finally, it test the retrained model and give out the final model with its accuracy. 
```bash
python autorun.py
```